@@ -44,7 +44,7 @@ NUM_POINT = 30 # Number of timepoints in a simulation
 
 
 def getTimeseries():
-    return NamedTimeseries(TEST_DATA_PATH)
+    return NamedTimeseries(csvPath=TEST_DATA_PATH)
 
 def getFitter(cls=ModelFitterCore, isPlot=False, **kwargs):
     return cls(ANTIMONY_MODEL, getTimeseries(), list(PARAMETER_DCT.keys()),
